app property
Firebase app name for multi-app configurations.
When null, uses the default Firebase app. When specified, uses the named app. Useful for projects that need to connect to multiple Firebase projects.
Implementation
final String? app;
Firebase app name for multi-app configurations.
When null, uses the default Firebase app. When specified, uses the named app. Useful for projects that need to connect to multiple Firebase projects.
final String? app;