limit property
Maximum number of documents to fetch in collection queries.
This limit applies to:
- Collection streams (
streams) - Collection futures (
futures) - Search operations
- Sub-collection operations
Default value is 10. Set to a higher value for larger datasets, but be mindful of performance and Firestore costs.
Implementation
final int limit;