path property
Firestore collection path.
This is the path to the Firestore collection where documents will be stored and retrieved. Examples: 'users', 'products', 'orders'.
Implementation
final String path;
Firestore collection path.
This is the path to the Firestore collection where documents will be stored and retrieved. Examples: 'users', 'products', 'orders'.
final String path;